@@ -8,6 +8,7 @@
 
 #include <QUrl>
 
+#include "Category/Category.h"
 #include <QQuickView>
 
 class AbstractResource;
@@ -17,6 +18,7 @@ class QWindow;
 class QQmlApplicationEngine;
 class CachedNetworkAccessManagerFactory;
 class TransactionsJob;
+class InlineMessage;
 
 #define DISCOVER_BASE_URL "qrc:/qt/qml/org/kde/discover/qml"
 
@@ -24,8 +26,8 @@ class DiscoverObject : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool isRoot READ isRoot CONSTANT)
-    Q_PROPERTY(QRect initialGeometry READ initialGeometry CONSTANT)
     Q_PROPERTY(QQuickWindow *mainWindow READ mainWindow CONSTANT)
+    Q_PROPERTY(InlineMessage *homePageMessage READ homePageMessage NOTIFY homeMessageChanged)
 
 public:
     explicit DiscoverObject(const QVariantMap &initialProperties);
@@ -43,10 +45,13 @@ public:
     QQuickWindow *mainWindow() const;
     void showError(const QString &msg);
     Q_INVOKABLE void copyTextToClipboard(const QString text);
-    QRect initialGeometry() const;
+    Q_INVOKABLE QUrl searchUrl(const QString searchText);
 
     QString describeSources() const;
     Q_SCRIPTABLE void restore();
+    [[nodiscard]] InlineMessage *homePageMessage() const;
+
+    Q_SCRIPTABLE bool quitWhenIdle();
 
 public Q_SLOTS:
     void openApplication(const QUrl &app);
@@ -54,9 +59,11 @@ public Q_SLOTS:
     void openCategory(const QString &category);
     void openMode(const QString &mode);
     void openLocalPackage(const QUrl &localfile);
+    void startHeadlessUpdate();
 
-    void reboot();
+    void promptReboot();
     void rebootNow();
+    void shutdownNow();
 
 private Q_SLOTS:
     void switchApplicationLanguage();
@@ -65,25 +72,27 @@ Q_SIGNALS:
     void openSearch(const QString &search);
     void openApplicationInternal(AbstractResource *app);
     void listMimeInternal(const QString &mime);
-    void listCategoryInternal(Category *cat);
+    void listCategoryInternal(const std::shared_ptr<Category> &cat);
 
     void unableToFind(const QString &resid);
     void
     openErrorPage(const QString &errorMessage, const QString &errorExplanation, const QString &buttonText, const QString &buttonIcon, const QString &buttonURL);
+    void homeMessageChanged();
 
 private:
     void showLoadingPage();
     void initMainWindow(QQuickWindow *mainWindow);
-    bool quitWhenIdle();
     void reconsiderQuit();
+    void setAboutToReboot();
+    void setAboutToPowerOff();
     QQmlApplicationEngine *engine() const
     {
-        return m_engine;
+        return m_engine.get();
     }
 
-    QQmlApplicationEngine *const m_engine;
+    std::unique_ptr<QQmlApplicationEngine, QScopedPointerDeleteLater> m_engine;
     std::unique_ptr<QQuickWindow> m_mainWindow;
-
-    QScopedPointer<CachedNetworkAccessManagerFactory> m_networkAccessManagerFactory;
-    KStatusNotifierItem *m_sni = nullptr;
+    std::unique_ptr<CachedNetworkAccessManagerFactory> m_networkAccessManagerFactory;
+    std::unique_ptr<KStatusNotifierItem, QScopedPointerDeleteLater> m_sni;
+    std::unique_ptr<InlineMessage> m_homePageMessage;
 };
