@@ -23,6 +23,7 @@
 #include <resources/StoredResultsStream.h>
 
 using namespace Qt::StringLiterals;
+using namespace Utils;
 
 class FlatpakSourceItem : public QStandardItem
 {
@@ -63,16 +64,21 @@ public:
                     return;
                 }
 
-                if (requestedDisabled) {
-                    m_backend->unloadRemote(m_installation, m_remote);
-                } else {
-                    m_backend->loadRemote(m_installation, m_remote);
-                }
+                setRemoteLoaded(requestedDisabled);
             }
         }
         QStandardItem::setData(value, role);
     }
 
+    void setRemoteLoaded(bool loaded)
+    {
+        if (loaded) {
+            m_backend->loadRemote(m_installation, m_remote);
+        } else {
+            m_backend->unloadRemote(m_installation, m_remote);
+        }
+    }
+
     FlatpakRemote *remote() const
     {
         return m_remote;
@@ -245,7 +251,7 @@ bool FlatpakSourcesBackend::removeSource(const QString &id)
                 if (installedRef) {
                     auto res = backend->getAppForInstalledRef(installation, installedRef);
                     const auto name = QString::fromUtf8(flatpak_ref_get_name(ref));
-                    const auto refString = QString::fromUtf8(flatpak_ref_format_ref(ref));
+                    const auto refString = QString::fromUtf8(flatpak_ref_format_ref_cached(ref));
                     if (!name.endsWith(QLatin1String(".Locale"))) {
                         if (res) {
                             toRemoveHash[res->name()] << refString;
@@ -296,6 +302,7 @@ bool FlatpakSourcesBackend::removeSource(const QString &id)
 
         g_autoptr(GError) errorRemoveRemote = nullptr;
         if (flatpak_installation_remove_remote(installation, id.toUtf8().constData(), cancellable, &errorRemoveRemote)) {
+            sourceItem->setRemoteLoaded(false);
             m_sources->removeRow(sourceItem->row());
 
             if (m_sources->rowCount() == 0) {
@@ -325,8 +332,8 @@ void FlatpakSourcesBackend::addRemote(FlatpakRemote *remote, FlatpakInstallation
         return;
     }
     const QString id = QString::fromUtf8(flatpak_remote_get_name(remote));
-    const QString title = QString::fromUtf8(flatpak_remote_get_title(remote));
-    const QUrl remoteUrl(QString::fromUtf8(flatpak_remote_get_url(remote)));
+    const QString title = copyAndFree(flatpak_remote_get_title(remote));
+    const QUrl remoteUrl(copyAndFree(flatpak_remote_get_url(remote)));
 
     const auto theActions = actions();
     for (const auto &variant : theActions) {
@@ -364,7 +371,7 @@ void FlatpakSourcesBackend::addRemote(FlatpakRemote *remote, FlatpakInstallation
     it->setData(prio, PrioRole);
     it->setCheckState(flatpak_remote_get_disabled(remote) ? Qt::Unchecked : Qt::Checked);
 #if FLATPAK_CHECK_VERSION(1, 4, 0)
-    it->setData(QString::fromUtf8(flatpak_remote_get_icon(remote)), IconUrlRole);
+    it->setData(copyAndFree(flatpak_remote_get_icon(remote)), IconUrlRole);
 #endif
     it->setCheckable(true);
     it->setFlatpakInstallation(installation);
