@@ -18,7 +18,7 @@ class QProcess;
 class PackageKitNotifier : public BackendNotifierModule
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.discover.BackendNotifierModule")
+    Q_PLUGIN_METADATA(IID DISCOVER_NOTIFIER_IID)
     Q_INTERFACES(BackendNotifierModule)
 public:
     explicit PackageKitNotifier(QObject *parent = nullptr);
@@ -38,7 +38,7 @@ private Q_SLOTS:
     void package(PackageKit::Transaction::Info info, const QString &packageID, const QString &summary);
     void finished(PackageKit::Transaction::Exit exit, uint);
     void onRequireRestart(PackageKit::Transaction::Restart type, const QString &packageID);
-    void transactionListChanged(const QStringList &tids);
+    void transactionListChanged(const QStringList &transactionIDs);
 
 private:
     void nowNeedsReboot();
